@@ -5,6 +5,7 @@
 #endif
 
 //#include "esp_crc.h"
+#include "esp_efuse.h"
 #include "esp_log.h"
 #include "esp_debug_helpers.h"
 
@@ -15,6 +16,12 @@
 #include "esp_interface.h"
 #include "esp_ipc.h"
 
+#ifdef ESP_IDF_COMP_CONSOLE_ENABLED
+#include "esp_console.h"
+#include "linenoise/linenoise.h"
+#include "argtable3/argtable3.h"
+#endif
+
 #ifdef ESP_IDF_COMP_ESP_PM_ENABLED
 #include "esp_pm.h"
 #endif
@@ -76,6 +83,10 @@
 
 #ifdef ESP_IDF_COMP_FATFS_ENABLED
 #include "esp_vfs_fat.h"
+#include "diskio_impl.h"
+#include "diskio_rawflash.h"
+#include "diskio_sdmmc.h"
+#include "diskio_wl.h"
 #endif
 
 #endif
